__doc__ = f"""
Usage: {__file__} [options] [FILE] ...
       {__file__} (--left | --right) STEP1 STEP2

Process FILE and optionally apply correction to either left-hand side or
right-hand side.

Arguments:
  FILE        optional input file
  STEP1 STEP2 STEP1, STEP2 --left or --right to be present

Options:
  --help
  --verbose      verbose mode
  --quiet        quiet mode
  --report       make report

"""

from docopt import magic

magic()

"""
prints:
{'--help': False,
 '--left': False,
 '--quiet': False,
 '--report': False,
 '--right': False,
 '--verbose': False,
 'FILE': [],
 'STEP1': None,
 'STEP2': None}
"""

print(arguments)  # noqa: F821

"""
prints:
False
"""
print(arguments.left)  # noqa: F821



"""usage: git add [options] [--] [<filepattern>...]

    -h, --help
    -n, --dry-run        dry run
    -v, --verbose        be verbose

    -i, --interactive    interactive picking
    -p, --patch          select hunks interactively
    -e, --edit           edit current diff and apply
    -f, --force          allow adding otherwise ignored files
    -u, --update         update tracked files
    -N, --intent-to-add  record only the fact that the path will be added later
    -A, --all            add all, noticing removal of tracked files
    --refresh            don't add, only refresh the index
    --ignore-errors      just skip files which cannot be added because of errors
    --ignore-missing     check if - even missing - files are ignored in dry run

"""
from docopt import docopt


if __name__ == "__main__":
    print(docopt(__doc__))
